@@ -23,7 +23,7 @@ struct zbinbuf{
 struct zbinbuf *zbinbuf_init(void);
 void zbinbuf_free(struct zbinbuf *zbb);
 void zbinbuf_append_bin(struct zbinbuf *zbb, const void *data, int len);
-void zbinbuf_append(struct zbinbuf *zbb, char *str);
+void zbinbuf_append(struct zbinbuf *zbb, const char *str);
 int zbinbuf_sprintf(struct zbinbuf *zbb, char *fmt, ...);
 int zbinbuf_sprintfa(struct zbinbuf *zbb, char *fmt, ...);
 void zbinbuf_prepend(struct zbinbuf *zbb, void *data, int len);
