@@ -18,7 +18,8 @@
 
 void zfence_init(gsize padsize, char padchar, int memvalue);
 void zfence_free(void);
-void zfence_check(void);
+void zfence_check(const char *fname);
+void zfence_start(void);
 
 gpointer zfence_malloc(gsize n_bytes);
 gpointer zfence_realloc (gpointer mem, gsize n_bytes);
