@@ -23,6 +23,10 @@ char *x2gramin(char *buf, int size, double x, char *signs);
  
 int qrbqtf(char *myqth,char *recqth,double *qrb,double *qtf,GString *gs_debug, int flags);
 int hw2qrbqtf(double h1, double w1, double h2, double w2, double *qrb, double *qtf);
+void hw2km(double h1, double w1, double h2, double w2, int *kx, int *ky);
+void hw2km_d(double h1, double w1, double h2, double w2, double *kx, double *ky);
+void hw2km_f(double h1, double w1, double h2, double w2, float *kx, float *ky);
+void km2qrbqtf(int kx, int ky, double *qrb, double *qtf);
 
 int qrbqtf2hw(double h1, double w1, double qrb, double qtf, double *h2, double *w2);
 int qsopwr( char *myqth, char *recqth);
