@@ -56,7 +56,7 @@ static inline char *z_str_uc(char *str){
 }
 
 static inline char *z_strlcpy(gchar *dest, const gchar *src, gsize dest_size){
-    if (dest == NULL){
+    if (src == NULL){
         g_strlcpy(dest, "", dest_size);
     }else{
         g_strlcpy(dest, src, dest_size);
