@@ -122,7 +122,9 @@ struct zcor *zcor_calc(double myh, double myw, gchar *locator, struct zselect *z
 }
 
 void zcors_recalc(double myh, double myw, gchar *locator, struct zselect *zsel, void (*callback)(void), const struct cpoint *file, int cor_items){ 
-    //dbg("--------\ncor_recalc('%s', '%s') %d %d\n", sw->title, locator, sw->myh, sw->myw);
+	char tmploc[10];
+	hw2loc(tmploc, myh * 180.0/M_PI, myw * 180.0/M_PI, 6);
+    dbg("--------\ncor_recalc('%s')\n", tmploc);
 
 	if (gcor && strcmp(gcor->loc, locator) == 0){
 		//dbg("same locators as gcor\n");
