@@ -59,13 +59,21 @@ struct zhttp *zhttp_init(void){
 	http->cookies = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 	http->headers = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free); /* TODO: who should free it? */
 	http->sock = -1;
+	//dbg("zhttp_init(%p)\n", http);
+
 	return http;
 }
 
 void zhttp_free(struct zhttp *http){
+	//dbg("zhttp_free(%p)\n", http);
 	if (!http) return;
 	if (http->sock >= 0){
 		zselect_set(http->zsel, http->sock, NULL, NULL, NULL, NULL);
+#ifdef Z_HAVE_GNUTLS
+		if (http->istls){
+			gnutls_deinit(http->session);
+		}
+#endif
 		closesocket(http->sock);
 		http->sock = -1;
 	}
@@ -83,9 +91,9 @@ void zhttp_free(struct zhttp *http){
 	zhttp_post_free(http);
 	g_free(http->datastr);
 	if (http->connecting_timer_id > 0) zselect_timer_kill(http->zsel, http->connecting_timer_id);
-#ifdef Z_HAVE_GNUTLS
-	gnutls_deinit(http->session);
-#endif
+//#ifdef Z_HAVE_GNUTLS
+//	gnutls_deinit(http->session);
+//#endif
 
 	g_free(http);
 }
@@ -109,6 +117,11 @@ void zhttp_post_free(struct zhttp *http){
 void zhttp_disconnect(struct zhttp *http, char *errorstr){
 	if (http->sock >= 0){
 		zselect_set(http->zsel, http->sock, NULL, NULL, NULL, NULL);
+#ifdef Z_HAVE_GNUTLS
+		if (http->istls){
+			gnutls_deinit(http->session);
+		}
+#endif
 		closesocket(http->sock);
 		http->sock = -1;
 	}
@@ -283,8 +296,6 @@ void zhttp_add_header(struct zhttp *http, const char *name, const char *value)
 }
 
 void zhttp_raw(struct zhttp *http, struct zselect *zsel, const char *url, const char *raw_request,  void (*callback)(struct zhttp *), void *arg){
-	struct zbinbuf *zbb;
-
 	zhttp_prepare1(http, zsel, url, arg);
 	zbinbuf_append(http->request, raw_request);
 	zhttp_do(http, zsel, callback);
@@ -526,9 +537,9 @@ static void zhttp_tls_handshake(void *arg){
 		return;
 	}
 	
-	char *desc = gnutls_session_get_desc(http->session);
-	dbg("Session info: %s\n", desc);
-	gnutls_free(desc);
+	//char *desc = gnutls_session_get_desc(http->session);
+	//dbg("Session info: %s\n", desc);
+	//gnutls_free(desc);
 	zselect_set(http->zsel, http->sock, NULL, zhttp_write_handler, NULL, http);
 	http->state = ZHTTPST_REQUEST;
 }
@@ -548,17 +559,24 @@ static void zhttp_write_handler(void *arg){
 #ifdef Z_HAVE_GNUTLS
 	if (http->istls){
 		ret = gnutls_record_send(http->session, http->request->buf, tosend);
+		if (ret < 0){
+			if (gnutls_error_is_fatal(ret) == 0) return;
+
+			zhttp_disconnect(http, g_strdup_printf("Error writing gnutls: %s", gnutls_strerror(ret)));
+			return;
+		}
 	}else
 #endif
 	{
 		ret = send(http->sock, http->request->buf, tosend, 0);
+		if (ret <= 0){
+			zhttp_disconnect(http, g_strdup_printf("Error writing http socket: %s", z_sock_strerror()));
+			return;
+		}
 	}
 
     //dbg("send(%d) = %d\n", tosend, ret);
-	if (ret <= 0){
-		zhttp_disconnect(http, g_strdup_printf("Error writing http socket: %s", z_sock_strerror()));
-		return;
-	}
+	
 
 	http->sent += ret;
 
@@ -599,19 +617,24 @@ static void zhttp_read_handler(void *arg){
 #ifdef Z_HAVE_GNUTLS
 	if (http->istls){
 		ret = gnutls_record_recv(http->session, buf, torecv);
-		if (ret < 0 && gnutls_error_is_fatal(ret) == 0) {
-			return;
+		if (ret < 0){
+			if (gnutls_error_is_fatal(ret) == 0) return;
+			if (ret == GNUTLS_E_PREMATURE_TERMINATION){ // fix for https://tilecache.rainviewer.asia
+				ret = 0;
+			}else{
+				zhttp_disconnect(http, g_strdup_printf("Error reading gnutls: %s", gnutls_strerror(ret)));
+			}
 		}
 	}else
 #endif
 	{
 		ret = recv(http->sock, buf, torecv, 0);
+		if (ret < 0){
+			zhttp_disconnect(http, g_strdup_printf("Error reading http socket: %s", z_sock_strerror()));
+			return;
+		}
 	}
 
-	if (ret < 0){
-		zhttp_disconnect(http, g_strdup_printf("Error reading http socket: %s", z_sock_strerror()));
-		return;
-	}
 	
 	if (ret == 0){
 		int ofs = 0;
