@@ -184,7 +184,9 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 	int png_num_palette;
 	png_bytep *volatile row_pointers;
 	int row, i;
+#ifdef SDL_SRCCOLORKEY
 	volatile int ckey = -1;
+#endif
 	png_color_16 *transv;
 
 	if ( !src ) {
@@ -259,13 +261,19 @@ static SDL_Surface *IMG_LoadPNG_RW(SDL_RWops *src)
 			    break;
 		    if(i == num_trans) {
 			/* exactly one transparent index */
-			ckey = t;
+#ifdef SDL_SRCCOLORKEY
+				ckey = t;
+#endif
 		    } else {
 			/* more than one transparent index, or translucency */
 			png_set_expand(png_ptr);
 		    }
-		} else
-		    ckey = 0; /* actual value will be set later */
+		}
+		else{
+#ifdef SDL_SRCCOLORKEY
+			ckey = 0; /* actual value will be set later */
+#endif
+		}
 	}
 
 	if ( color_type == PNG_COLOR_TYPE_GRAY_ALPHA )
