@@ -1171,7 +1171,7 @@ unsigned char z_b(SDL_Surface *surface, int color){
     return b;
 }
 
-
+#ifdef Z_HAVE_SDL1
 void z_dumpbitmap(SDL_Surface *screen, SDL_Surface *surface){
     SDL_Rect r;
     SDL_Surface *backup;
@@ -1214,7 +1214,16 @@ void z_dumpbitmap(SDL_Surface *screen, SDL_Surface *surface){
     SDL_SetAlpha(surface, SDL_SRCALPHA, surfacealpha);
 #endif
 }
+#endif
 
+#ifdef Z_HAVE_SDL2
+void z_dumpbitmap(SDL_Surface *unused, SDL_Surface *surface){
+	SDL_Window *window = SDL_CreateWindow("z_dumpbitmap", SDL_WINDOWPOS_CENTERED, SDL_WINDOWPOS_CENTERED, surface->w, surface->h, 0);
+	SDL_Surface *screen = SDL_GetWindowSurface(window);
+	SDL_BlitSurface(surface, NULL, screen, NULL);
+	SDL_UpdateWindowSurface(window);
+}
+#endif
 
 void zsdl_font_save(SDL_Surface *screen){
 #ifdef Z_HAVE_LIBPNG
