@@ -1,6 +1,6 @@
 /*
     string utilities
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -209,7 +209,7 @@ char *z_string_hex(GString *gs, char *data, int len){
 	
 	for (i = 0; i < len; i++){
 		if (i > 0) g_string_append_c(gs, ' ');
-		g_string_sprintfa(gs, "%02x", (unsigned char)data[i]);
+		g_string_append_printf(gs, "%02x", (unsigned char)data[i]);
 	}
     return gs->str;
 }
